@@ -424,7 +424,8 @@ function import_avatar_gallery($gallery_name = '', $subdirs_as_galleries = false
 
 	$relative_path = empty($convert->convertor['source_path_absolute']);
 
-	if (empty($convert->convertor['avatar_gallery_path']))
+	// check for trailing slash
+	if (rtrim($convert->convertor['avatar_gallery_path'], '/') === '')
 	{
 		$convert->p_master->error(sprintf($user->lang['CONV_ERROR_NO_GALLERY_PATH'], 'import_avatar_gallery()'), __LINE__, __FILE__);
 	}
@@ -588,7 +589,8 @@ function import_attachment($source, $use_target = false)
 
 	global $convert, $phpbb_root_path, $config, $user;
 
-	if (empty($convert->convertor['upload_path']))
+	// check for trailing slash
+	if (rtrim($convert->convertor['upload_path'], '/') === '')
 	{
 		$convert->p_master->error(sprintf($user->lang['CONV_ERROR_NO_UPLOAD_DIR'], 'import_attachment()'), __LINE__, __FILE__);
 	}
@@ -647,7 +649,8 @@ function import_smiley($source, $use_target = false)
 
 	global $convert, $phpbb_root_path, $config, $user;
 
-	if (!isset($convert->convertor['smilies_path']))
+	// check for trailing slash
+	if (rtrim($convert->convertor['smilies_path'], '/') === '')
 	{
 		$convert->p_master->error(sprintf($user->lang['CONV_ERROR_NO_SMILIES_PATH'], 'import_smiley()'), __LINE__, __FILE__);
 	}
@@ -667,7 +670,8 @@ function import_avatar($source, $use_target = false, $user_id = false)
 
 	global $convert, $phpbb_root_path, $config, $user;
 
-	if (!isset($convert->convertor['avatar_path']))
+	// check for trailing slash
+	if (rtrim($convert->convertor['avatar_path'], '/') === '')
 	{
 		$convert->p_master->error(sprintf($user->lang['CONV_ERROR_NO_AVATAR_PATH'], 'import_avatar()'), __LINE__, __FILE__);
 	}
